@@ -70,7 +70,6 @@ class Protocol(threading.local):
             self.connection.connect(server)
         else:
             self.connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            self.connection.settimeout(5)
             self.host, self.port = self.split_host_port(self.server)
             self.connection.connect((self.host, self.port))
 
@@ -147,7 +146,7 @@ class Protocol(threading.local):
         :rtype: bool
         """
         logger.info('Authenticating as %s' % username)
-        self.connection.send(struct.pack(self.HEADER_STRUCT,
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT,
                                          self.MAGIC['request'],
                                          self.COMMANDS['auth_negotiation']['command'],
                                          0, 0, 0, 0, 0, 0, 0))
@@ -167,7 +166,7 @@ class Protocol(threading.local):
 
         method = 'PLAIN'
         auth = '\x00%s\x00%s' % (username, password)
-        self.connection.send(struct.pack(self.HEADER_STRUCT +
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT +
                                          self.COMMANDS['auth_request']['struct'] % (len(method), len(auth)),
                                          self.MAGIC['request'], self.COMMANDS['auth_request']['command'],
                                          len(method), 0, 0, 0, len(method) + len(auth), 0, 0, method, auth))
@@ -247,7 +246,7 @@ class Protocol(threading.local):
         :rtype: object
         """
         logger.info('Getting key %s' % key)
-        self.connection.send(struct.pack(self.HEADER_STRUCT +
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT +
                                          self.COMMANDS['get']['struct'] % (len(key)),
                                          self.MAGIC['request'],
                                          self.COMMANDS['get']['command'],
@@ -296,7 +295,7 @@ class Protocol(threading.local):
                            self.COMMANDS['getk']['command'],
                            len(last), 0, 0, 0, len(last), 0, 0, last)
 
-        self.connection.send(msg)
+        self.connection.sendall(msg)
 
         d = {}
         opcode = -1
@@ -331,7 +330,7 @@ class Protocol(threading.local):
         flags, value = self.serialize(value)
         logger.info('Value bytes %d.' % len(value))
 
-        self.connection.send(struct.pack(self.HEADER_STRUCT +
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT +
                                          self.COMMANDS[command]['struct'] % (len(key), len(value)),
                                          self.MAGIC['request'],
                                          self.COMMANDS[command]['command'],
@@ -433,7 +432,7 @@ class Protocol(threading.local):
 
         msg = ''.join(msg)
 
-        self.connection.send(msg)
+        self.connection.sendall(msg)
 
         opcode = -1
         retval = True
@@ -460,7 +459,7 @@ class Protocol(threading.local):
         :return: Actual value of the key on server
         :rtype: int
         """
-        self.connection.send(struct.pack(self.HEADER_STRUCT +
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT +
                                          self.COMMANDS[command]['struct'] % len(key),
                                          self.MAGIC['request'],
                                          self.COMMANDS[command]['command'],
@@ -521,7 +520,7 @@ class Protocol(threading.local):
         :rtype: bool
         """
         logger.info('Deletting key %s' % key)
-        self.connection.send(struct.pack(self.HEADER_STRUCT +
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT +
                                          self.COMMANDS['delete']['struct'] % len(key),
                                          self.MAGIC['request'],
                                          self.COMMANDS['delete']['command'],
@@ -546,7 +545,7 @@ class Protocol(threading.local):
         :rtype: bool
         """
         logger.info('Flushing memcached')
-        self.connection.send(struct.pack(self.HEADER_STRUCT +
+        self.connection.sendall(struct.pack(self.HEADER_STRUCT +
                                          self.COMMANDS['flush']['struct'],
                                          self.MAGIC['request'],
                                          self.COMMANDS['flush']['command'],
@@ -585,7 +584,7 @@ class Protocol(threading.local):
                 self.COMMANDS['stat']['command'],
                 0, 0, 0, 0, 0, 0, 0)
 
-        self.connection.send(packed)
+        self.connection.sendall(packed)
 
         value = {}
 
